<?php

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2013 Thomas Deuling <typo3@coding.ms>, coding.ms
 *  
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 *
 *
 * @package ftm
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 */
class Tx_Ftm_Controller_TemplateManagerController extends Tx_Extbase_MVC_Controller_ActionController {

    /**
     * Page-Id auf der das FTM-Template liegt
     *
     * @var integer
     */
    protected $pid = 0;

    /**
     * Template Model
     *
     * @var Tx_Ftm_Domain_Repository_Template
     */
    protected $fluidTemplate = NULL;

    /**
     * Template Repository
     *
     * @var Tx_Ftm_Domain_Repository_TemplateRepository
     */
    protected $fluidTemplateRepository;

    /**
     * GridLayout Repository
     *
     * @var Tx_Ftm_Domain_Repository_GridLayoutRepository
     */
    protected $gridLayoutRepository;

    /**
     * PluginCloud-Service
     *
     * @var Tx_Ftm_Service_PluginService
     */
    protected $pluginService;

    /**
     * Fluid-Service
     *
     * @var Tx_Ftm_Service_Fluid
     */
    protected $fluidService;

    /**
     * Pages-Service
     *
     * @var Tx_Ftm_Service_Pages
     */
    protected $pagesService;

    /**
     * TYAML-Service
     *
     * @var Tx_Ftm_Service_Tyaml
     */
    protected $tyamlService;
    
    /**
     * Extension-Konfiguration
     *
     * @var array
     */
    protected $extConf;

    /**
     * TYPO3-Version
     * @var float
     */
    protected $typo3Version = 0.0;

    /**
     * Debugging
     * @var string
     */
    protected $debug = "";

    /**
     * SysTemplate-Service
     *
     * @var Tx_Ftm_Service_SysTemplate
     */
    protected $sysTemplateService;

    /**
     * Session-Handler
     *
     * @var Tx_Ftm_Domain_Session_SessionHandler
     */
    protected $sessionHandler = null;

    /**
     * injectTemplateRepository
     *
     * @param Tx_Ftm_Domain_Repository_TemplateRepository $fluidTemplateRepository
     * @return void
     */
    public function injectTemplateRepository(Tx_Ftm_Domain_Repository_TemplateRepository $fluidTemplateRepository) {
        $this->fluidTemplateRepository = $fluidTemplateRepository;
    }

    /**
     * injectGridLayoutRepository
     *
     * @param Tx_Ftm_Domain_Repository_GridLayoutRepository $gridLayoutRepository
     * @return void
     */
    public function injectGridLayoutRepository(Tx_Ftm_Domain_Repository_GridLayoutRepository $gridLayoutRepository) {
        $this->gridLayoutRepository = $gridLayoutRepository;
    }

    /**
     * injectFluidService
     *
     * @param Tx_Ftm_Service_Fluid $fluidService
     * @return void
     */
    public function injectFluidService(Tx_Ftm_Service_Fluid $fluidService) {
        $this->fluidService = $fluidService;
    }

    /**
     * injectPagesService
     *
     * @param Tx_Ftm_Service_Pages $pagesService
     * @return void
     */
    public function injectPagesService(Tx_Ftm_Service_Pages $pagesService) {
        $this->pagesService = $pagesService;
    }

    /**
     * injectTyamlService
     *
     * @param Tx_Ftm_Service_Tyaml $tyamlService
     * @return void
     */
    public function injectTyamlService(Tx_Ftm_Service_Tyaml $tyamlService) {
        $this->tyamlService = $tyamlService;
    }

    /**
     * injectSysTemplate
     *
     * @param Tx_Ftm_Service_SysTemplate $sysTemplateService
     * @return void
     */
    public function injectSysTemplate(Tx_Ftm_Service_SysTemplate $sysTemplateService) {
        $this->sysTemplateService = $sysTemplateService;
    }
    
    /**
     * Action initialisieren
     * Wird immer aufgerufen wenn irgendeine Action ausgefuehrt wird
     */
    public function initializeAction() {
            
        // error_reporting(E_ALL);
        // ini_set('display_errors', 1);
        
        // Sicherstellen das hier nur ein Admin arbeitet!
        if(!$GLOBALS['BE_USER']->isAdmin()) {
            throw new Exception("Admin-Authorisation required", 1);
        }
        
        $compatVersion = explode('.', $GLOBALS['TYPO3_CONF_VARS']['SYS']['compat_version']);
        $this->typo3Version = (float)($compatVersion[0].'.'.$compatVersion[1]);
        
        // Extension-Konfiguration auslesen
        $this->extConf = unserialize($GLOBALS['TYPO3_CONF_VARS']['EXT']['extConf']['ftm']);
        $this->validateExtConf();
        
        // Aktuelle Page auslesen
        $this->pid = intval($_GET['id']);
        if($this->pid==0) {
            if($this->typo3Version>=6) {
                die("Please select a first-level page in order to create or edit a FTM-Template.");
            }
            else {
                $this->flashMessageContainer->add("Please select a first-level page in order to create or edit a FTM-Template.", 'Please select a page!', t3lib_FlashMessage::WARNING);
            }
            return;
        }
        
            
    
        // Fluid Template auslesen, falls noch nicht geschehen
        if(!($this->fluidTemplate instanceof Tx_Ftm_Domain_Model_Template)) {
            
            /**
             * @var Tx_Ftm_Domain_Model_Template
             */
            $this->fluidTemplate = $this->getTemplate();
        }
        
        // SysTemplate-Service erstellen, falls noch nicht geschehen
        if(!($this->sysTemplateService instanceof Tx_Ftm_Service_SysTemplate)) {
            $this->sysTemplateService = $this->objectManager->create('Tx_Ftm_Service_SysTemplate');
        }
        
        // Fluid-Service erstellen, falls noch nicht geschehen
        if(!($this->fluidService instanceof Tx_Ftm_Service_Fluid)) {
            $this->fluidService = $this->objectManager->create('Tx_Ftm_Service_Fluid');
        }
        
        // Pages-Service erstellen, falls noch nicht geschehen
        if(!($this->pagesService instanceof Tx_Ftm_Service_Pages)) {
            $this->pagesService = $this->objectManager->create('Tx_Ftm_Service_Pages');
        }
               
        
        // PluginCloud-Service initiieren
        $this->pluginService = $this->objectManager->create(
            'Tx_Ftm_Service_PluginService', 
            $this->extConf['pluginCloudHost'],
            $this->extConf['pcKey'],
            $this->extConf['user'],
            $this->extConf['password']
        );
        
        
    }
    

    /**
     * action list
     *
     * @return void
     */
    public function listAction() {
        
        
        // Auf Root-Seite nichts machen
        // Meldung wurde bereits in initializeAction generiert
        if($this->pid==0) {
            return;
        }
        // error_reporting(E_ALL);
        // ini_set('display_errors', 1);
        
        
        $this->checkRequiredExtenstions();
        
        // Preufen ob Updates verfuegbar sind
        $updateMessage = $this->checkForUpdates();
        if(is_string($updateMessage)) {
            $this->flashMessageContainer->add($updateMessage, 'FTM Update verfügbar!', t3lib_FlashMessage::WARNING);
        }

       
        $buttons = array();
        $options = array();
        $options['ftmVersion'] = FTM_VERSION;
        $options['pid']        = $this->pid;
        $options['wikiUrl']    = 'http://if-20.com/iframes/fluid-template-manager-ftm-current-version/';
        $options['twitterUrl'] = 'http://if-20.com/iframes/IF-20-Twitter-Stream/';
        $options['disclaimerNotAccepted'] = true;
        
        
        // Pruefen ob es auf der aktuelle Seite schon ein
        // Template-Datensatz gibt
        if($this->fluidTemplate===null) {
            $options['templateOnCurrentPage'] = false;
            
            /**
             * @ToDo: Hier muss geprueft werden, ob ein Template auf einer
             * hoeheren Ebene/Seite existiert!
             * Ein neues Template zu erstellen sollte dann verboten werden!
             */
            
            $this->debug.="no template on this pid: ".$this->pid."<br>";
           
        }
        else {
            
            // Merken das es ein Template gibt
            // und pruefen ob Meldung noch angezeigt wird
            // -------------------------------------------------
            $options['templateOnCurrentPage'] = true;
            $options['disclaimerNotAccepted'] = !$this->fluidTemplate->isDisclaimerAccepted();
            $this->debug.="template on this pid: ".$this->pid."<br>";
        
        
            // Buttons im Header
            // -------------------------------------------------
            $buttons = $this->getButtons($this->fluidTemplate->getConfig()->getBaseUrl());
            
            
            // Pruefen ob das Sys-Template vorhanden ist
            // und erstellt es ggf.
            // -------------------------------------------------
            $sysTemplateStatus = $this->sysTemplateService->checkSysTemplate($this->pid);
            if($sysTemplateStatus=='error') {
                $headline = 'FTM Root-Template Fehler!';
                $message  = 'Es wurde ein Problem mit dem Root-Template auf dieser Seite festgestellt!<br/>';
                $message .= 'Bitte stellen Sie sicher das es nur ein Root-Template auf dieser Seite gibt!';
                $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::ERROR);
            }
            else if($sysTemplateStatus=='updated') {
                $headline = 'FTM Root-Template aktualisiert!';
                $message  = 'Das FTM Root-Template auf dieser Seite wurde aktualisiert!';
                $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::OK);
                
                // Seite neu laden
                $this->redirect('list', 'TemplateManager', NULL, array());
            }
            else if($sysTemplateStatus=='created') {
                
                $headline = 'FTM Root-Template erstellt!';
                $message  = 'Es wurde ein FTM Root-Template auf dieser Seite erstellt!';
                $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::OK);
                
                // Seite neu laden
                $this->redirect('list', 'TemplateManager', NULL, array());
            }
            // -------------------------------------------------
            
            
            
            // Sys-Template gefunden
            // -------------------------------------------------
            else if($sysTemplateStatus=='alreadyExist') {
                
                
                // Hash neu setzen um zu identifizieren ob 
                // sich die Konfiguration geaendert hat
                $templateDataArray = $this->getTemplateDataArray();
                $this->fluidTemplate->setMd5HashTemplateData(md5(serialize($templateDataArray)));
                $this->fluidTemplateRepository->update($this->fluidTemplate);
                
                
                // Fileadmin-Verzeichnis bereits vorhanden
                $fileadminPath = $this->fluidTemplate->getFileadminDir();
                if($fileadminPath!="") {
            
            
                    // Pruefen ob die erforderlichen Pages vorhanden
                    // sind und erstelle Sie ggf.
                    // -------------------------------------------------
                    $pagesMessages = $this->pagesService->checkPages($this->pid);
                    
                    // Meldungen von erstellten Seiten ausgeben
                    if(trim($pagesMessages)!="" && $pagesMessages!==true) {
                        $headline = 'FTM Seiten erstellt!';
                        $this->flashMessageContainer->add($pagesMessages, $headline, t3lib_FlashMessage::OK);
                    }
                    // -------------------------------------------------
                    
                    
                    $this->tyamlService->checkTyaml($this->pid);
                    
                    
                    
                    // fileadmin-Dir ggf nochmal in Sys-
                    // Template etc. setzen/aktualisieren
                    // -------------------------------------------------
                    $options['fileadminDirFound'] = true;
                    $this->setFileadminDir($fileadminPath);
                    // -------------------------------------------------
                    
                    
                    // Pruefen ob die Template-Verzeichnisstruktur
                    // vorhanden und korrekt ist
                    // -------------------------------------------------
                    $directoryCheck = Tx_Ftm_Service_TemplateDirectory::checkDirectories($fileadminPath);
                    if($directoryCheck===true) {
                        $this->debug.= "directory check: true<br>";
                    }
                    else {
                        if(!empty($directoryCreate)) {
                            foreach($directoryCreate as $directory => $description) {
                                $this->debug.= "directory '".$directory."' not found<br>";
                            }
                        }
                    }
                    
                    $directoryCreate = Tx_Ftm_Service_TemplateDirectory::createDirectories($fileadminPath);
                    if($directoryCreate===true) {
                        $this->debug.= "directory create: true<br>";
                    }
                    else {
                        if(!empty($directoryCreate)) {
                            foreach($directoryCreate as $directory => $description) {
                                $this->debug.= "couldnt create directory '".$directory."'. Please check permissions for directory /fileadmin/".$fileadminPath."/<br>";
                            }
                        }
                    }
                    // -------------------------------------------------
                    
                    
                    
                    // Pruefen ob alle Fluid-Templates vorhanden sind
                    // -------------------------------------------------
                    $tempMessages = "";
                    // Pruefen ob alle Layout-Datensaetze vorhanden sind
                    $fluidLayoutFiles   = $this->fluidService->checkFiles($this->fluidTemplate, 'layout');
                    if($fluidLayoutFiles===true) {
                        $this->debug.= "fluid layout files: true<br>";
                    }
                    else {
                        $tempMessages.= $this->fluidService->createFiles($this->fluidTemplate, 'layout', $fluidLayoutFiles);
                    }
                    
                    // Pruefen ob alle Partial-Datensaetze vorhanden sind
                    $fluidPartialFiles  = $this->fluidService->checkFiles($this->fluidTemplate, 'partial');
                    if($fluidPartialFiles===true) {
                        $this->debug.= "fluid partial files: true<br>";
                    }
                    else {
                        $tempMessages.= $this->fluidService->createFiles($this->fluidTemplate, 'partial', $fluidPartialFiles);
                    }
                    
                    // Pruefen ob alle Template-Datensaetze vorhanden sind
                    $fluidTemplateFiles = $this->fluidService->checkFiles($this->fluidTemplate, 'template');
                    if($fluidTemplateFiles===true) {
                        $this->debug.= "fluid template files: true<br>";
                    }
                    else {
                        $tempMessages.= $this->fluidService->createFiles($this->fluidTemplate, 'template', $fluidTemplateFiles);
                    }
                    
                    // Meldungen von erstellten Templates ausgeben
                    if(trim($tempMessages)!="") {
                        $headline = 'Fluid-Templates erstellt!';
                        $this->flashMessageContainer->add($tempMessages, $headline, t3lib_FlashMessage::OK);
                    }
                    // -------------------------------------------------
                    
                    
                }


                // -------------------------------------------------
                // fileadmin-Verzeichnis wurde noch nicht
                // im FTM-Template angegeben
                else {
                    
                    $options['fileadminDirFound'] = false;
                    
                    $headline = 'Kein fileadmin-Verzeichnis gefunden!';
                    $message  = 'In diesem FTM-Template ist noch kein fileadmin-Verzeichnis eingetragen worden.<br />';
                    $message .= 'Bitte editieren Sie den Template-Datensatz, und geben Sie im Feld fileadminDir den Namen des Verzeichnisses an in dem Ihre Template erstellt werden soll.<br />';
                    $message .= 'Sobald das FTM-Template ein fileadmin-Verzeichnis beinhaltet, wird die benötigte Verzeichnisstruktur gecheckt und ggf. erstellt!.';
                    $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::WARNING);
                }
            }
            
        }
        
        
    
                
        // Template befuellen
        $this->view->assign('buttons', $buttons);
        $this->view->assign('debug',   $this->debug);
        $this->view->assign('doDebug', false);
        $this->view->assign('options', $options);
        $this->view->assign('fluidTemplate', $this->fluidTemplate);
    }
    
    /**
     * Merkt sich das die Warnungen gelesen wurden!
     */
    public function acceptDisclaimerAction() {
        
        // Parameter auswerten
        if($this->request->hasArgument('acceptDisclaimer')) {
            $acceptDisclaimer = $this->request->getArgument('acceptDisclaimer');
            if($acceptDisclaimer=='true') {
                $this->fluidTemplate->setDisclaimerAccepted(true);
                $this->fluidTemplateRepository->update($this->fluidTemplate);
            }
        }

        $this->redirect('list', 'TemplateManager', NULL, array());
    }
        
    /**
     * Prueft ob es fuer diese Seite schon ein Template-Object
     * gibt, wenn nicht wird eins erstellt
     *
     * @return Tx_Ftm_Domain_Repository_Template
     */
    protected function getTemplate() {
        
        
        // Template auslesen, falls vorhanden
        $fluidTemplate = $this->fluidTemplateRepository->findOneByPid($this->pid);
        
        
        $this->debug.= "read fluidTemplate on pid:".$this->pid." -> ".get_class($fluidTemplate)."<br>";
        
        // Wenn es noch keinen gibt, erstelle einen
        if(!($fluidTemplate instanceof Tx_Ftm_Domain_Model_Template)) {

            $this->debug.= "create fluidTemplate on pid:".$this->pid."<br>";

            
            /**
             * @ToDo: Hier sollte geschaut werden ob auf 
             * Eltern-Seiten ein Template existiert
             */
            
            // Template speichern
            // $this->fluidTemplateRepository->add($fluidTemplate);
            return null;
        }
        
        return $fluidTemplate;
    }

    
    /**
     * Erstellt die Less-Variablen Datei zu einem FTM-Template
     *
     * @author Thomas Deuling <typo3@coding.ms>
     * @return void
     * @since 1.0.0
     */
    public function generateLessVariableAction() {
        
        // Pruefen ob FTM-Template vorhanden
        if(!($this->fluidTemplate instanceof Tx_Ftm_Domain_Model_Template)) {
            $headline = 'Less-Variablen nicht re-/generiert!';
            $message  = 'Die Less-Variablen konnte re-/generiert werden, da auf dieser Seite anscheinen noch kein FTM-Template existiert.';
            $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::ERROR);
        }
        
        else {
            
            // Less-Variablen ueber Web-Service generieren            
            $result = $this->pluginService->executeAction("generateLessVariable", $this->fluidTemplate->toArray());
            
            if($result['status']=='success') {
                
                $filepath = "fileadmin/".$this->fluidTemplate->getFileadminDir()."/template/less/0_basicLess/";
                $filename = "4_variables.less";
                $relPath = $filepath.$filename;
                $absPath = t3lib_div::getFileAbsFileName($relPath);
                $touchPath = t3lib_div::getFileAbsFileName($filepath);
                
                $defaults = "/* FTM - Less-Defaults: */\n";
                $defaults.= "@baseUrl         = \"".$this->fluidTemplate->getConfig()->getBaseUrl()."\";\n";
                $defaults.= "@baseUrlTemplate = \"".$this->fluidTemplate->getConfig()->getBaseUrl()."fileadmin/".$this->fluidTemplate->getFileadminDir()."/template/\";\n";
                $defaults.= "@fileadminDir    = \"".$this->fluidTemplate->getFileadminDir()."\";\n";
                $defaults.= "\n";
                $defaults.= "/* FTM - Less-Customs: */\n";
                
                // Versuche Datei zu aktualisieren
                Tx_Ftm_Service_Backup::backupFile($this->fluidTemplate, $absPath);
                if(!file_put_contents($absPath, $defaults.$result['lessVariable'])) {
                    $headline = 'Less-Variablen wurden re-/generiert!';
                    $message  = 'Die Less-Variablen für dieses FTM-Template wurde re-/generiert, konnte aber nicht in der ..less/0_basicLess/4_variables.less abgespeichert werden.<br />';
                    $message .= 'Bitte prüfen die Datei/Pfad auf Korrektheit und Schreibrechte: '.$absPath;
                    $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::ERROR);
                }
                else {
                    $headline = 'Less-Variablen wurden re-/generiert!';
                    $message  = 'Die Less-Variablen für dieses FTM-Template wurde re-/generiert.<br />';
                    $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::OK);
                }
            }
            else {
                $headline = 'Less-Variablen nicht re-/generiert!';
                $message  = 'Die Less-Variablen konnte re-/generiert werden, es gab einen Fehler beim Aufruf des Generierungs-WebServices.<br />';
                $message .= 'Bitte versuchen Sie es später noch einmal. Sollte der Fehler erneut auftreten kontaktieren Sie das Entwicklungs-Team..';
                $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::ERROR);
            }
            
            
        }
        
        
        $this->redirect('list', 'TemplateManager', NULL, array());
    }

    
    /**
     * Merkt sich einen Marker in der PluginCloud
     *
     * @author Thomas Deuling <typo3@coding.ms>
     * @param Tx_Ftm_Domain_Model_TemplateMarker $marker
     * @return void
     * @since 1.0.4
     */
    public function saveMarkerAction(Tx_Ftm_Domain_Model_TemplateMarker $marker) {
        
        // Infos fuer WebService ermitteln
        $data = $marker->toArray();
        $data['typo3Version'] = $typo3Version;
        // $data['fileadminDir'] = $this->fluidTemplate->getFileadminDir();
        // $data['baseUrl']      = $this->fluidTemplate->config->getBaseURL();
        $data['ftmVersion']   = FTM_VERSION;
        
        $result = $this->pluginService->executeAction("saveMarker", $data);
        
        if($result['status']=='success') {
            
            
             // Pfad ermitteln
            $typoScript = "";
            $messageOk  = "";
            $filepath   = "uploads/tx_ftm/";
            $relPath    = $filepath;
            $absPath    = t3lib_div::getFileAbsFileName($relPath);


            // Marker schreiben
            $markerFile       = "marker.serialized";
            $markerSerialized = $result['marker'];
            
            
            Tx_Ftm_Service_Backup::backupFile($this->fluidTemplate, $absPath.$markerFile);
            if(!file_put_contents($absPath.$markerFile, $markerSerialized)) {
                $headline = 'Snippets wurden ausgelesen!';
                $message  = 'Die Marker Snippets wurden ausgelesen, konnten aber nicht in der '.$markerFile.' abgespeichert werden.<br />';
                $message .= 'Bitte prüfe die Datei/Pfad auf Korrektheit und Schreibrechte: '.$absPath.$markerFile;
                $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::ERROR);
            }
            
            $headline = 'Marker wurde gemerkt!';
            $message  = 'Marker '.$marker->getMarkerName().' wurde in PluginCloud gemerkt.<br />';
            $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::OK);
        }
        else {
            $headline = 'Marker nicht gemerkt!';
            $message  = 'Marker '.$marker->getMarkerName().' konnte nicht in der PluginCloud gemerkt werden.<br />';
            $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::ERROR);
        }
        
        $this->redirect('list', 'TemplateManager', NULL, array());
    }

    
    /**
     * Setzt einen Marker aus der PluginCloud ein
     *
     * @author Thomas Deuling <typo3@coding.ms>
     * @param Tx_Ftm_Domain_Model_TemplateMarker $marker
     * @param string $markerName
     * @return void
     * @since 1.0.4
     */
    public function insertMarkerAction(Tx_Ftm_Domain_Model_TemplateMarker $marker, $markerName) {
        
        
        // Snippets auslesen
        $snippetFolder = t3lib_div::getFileAbsFileName("uploads/tx_ftm/");
        if(@file_exists($snippetFolder)) {
            $markerSerialized = file_get_contents($snippetFolder.'marker.serialized');
            $markerArray = unserialize($markerSerialized);
            
            // Marker-Vorlage suchen
            if(is_array($markerArray) && !empty($markerArray)) {
                foreach($markerArray as $tempMarker) {

                    if($tempMarker['markerName']==$markerName) {
                        $marker->setMarkerName($tempMarker['markerName']);
                        $marker->setMarkerType($tempMarker['markerType']);
                        $marker->setMarkerDescription($tempMarker['markerDescription']);
                        $marker->setMarkerTypoScript($this->removeSlashes($tempMarker['markerTypoScript']));
                    }
                    
                }
            }
        }
        
        
        $headline = 'Marker wurde eingefügt!';
        $message  = 'Marker-Vorlage '.$markerName.' wurde erfolgreich in Marker '.$marker->getMarkerName().' eingefügt.<br />';
        $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::OK);
            
        $this->redirect('list', 'TemplateManager', NULL, array());
    }

    protected function removeSlashes($text) {
        $text = str_replace("\\n", "\n", $text);
        $text = str_replace("\\r", "\r", $text);
        $text = str_replace("\\\"", "\"", $text);
        return $text;
    }

    /**
     * Liest alle Snippets (Marker, etc.) aus der PluginCloud
     *
     * @author Thomas Deuling <typo3@coding.ms>
     * @return void
     * @since 1.0.4
     */
    public function loadSnippetsAction() {
        
        // Infos fuer WebService ermitteln
        $data = array();
        $data['typo3Version'] = $this->typo3Version;
        // $data['fileadminDir'] = $this->fluidTemplate->getFileadminDir();
        // $data['baseUrl']      = $this->fluidTemplate->config->getBaseURL();
        $data['ftmVersion']   = FTM_VERSION;
        
        $result = $this->pluginService->executeAction("loadSnippets", $data);
        
        if($result['status']=='success') {
            
            
             // Pfad ermitteln
            $typoScript = "";
            $messageOk  = "";
            $filepath   = "uploads/tx_ftm/";
            $relPath    = $filepath;
            $absPath    = t3lib_div::getFileAbsFileName($relPath);


            // Marker schreiben
            $markerFile       = "marker.serialized";
            $markerSerialized = $result['marker'];
            
            
            Tx_Ftm_Service_Backup::backupFile($this->fluidTemplate, $absPath.$markerFile);
            if(!file_put_contents($absPath.$markerFile, $markerSerialized)) {
                $headline = 'Snippets wurden ausgelesen!';
                $message  = 'Die Marker Snippets wurden ausgelesen, konnten aber nicht in der '.$markerFile.' abgespeichert werden.<br />';
                $message .= 'Bitte prüfe die Datei/Pfad auf Korrektheit und Schreibrechte: '.$absPath.$markerFile;
                $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::ERROR);
            }
            
            
            $headline = 'Snippets wurden ausgelesen!';
            $message  = 'Es wurden alle Snippets aus der PluginCloud ausgelesen.<br />';
            $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::OK);
        }
        else {
            $headline = 'Snippets nicht ausgelesen!';
            $message  = 'Es konnten keine Snippets aus der PluginCloud ausgelesen werden.<br />';
            $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::ERROR);
        }
        
        $this->redirect('list', 'TemplateManager', NULL, array());
    }

    /**
     * Erstellt das TypoScript zu einem FTM-Template
     *
     * @param  string $typoScriptFile TypoScript-Datei die generiert werden soll (constants.ts oder setup.ts)
     * @author Thomas Deuling <typo3@coding.ms>
     * @return void
     * @since  1.0.0
     */
    public function generateTypoScriptAction($typoScriptFile) {
        
        
        // error_reporting(E_ALL);
        // ini_set('display_errors', 1);
        
        // Unterstuetzte TypoScript-dateien
        $validFiles = array();
        $validFiles[] = "constants.ts";
        $validFiles[] = "setup.ts";
        $validFiles[] = "tsConfig.ts";
        
        
        // TypoScript-Datei ok!?
        if(!in_array($typoScriptFile, $validFiles)) {
            throw new Exception("Error - TS '".$typoScriptFile."' file isn't valid", 1);
        }
        
        
        // Pruefen ob FTM-Template vorhanden
        if(!($this->fluidTemplate instanceof Tx_Ftm_Domain_Model_Template)) {
            $headline = 'TypoScript nicht re-/generiert!';
            $message  = 'Das '.$typoScriptFile.' TypoScript konnte re-/generiert werden, da auf dieser Seite anscheinend noch kein FTM-Template existiert.';
            $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::ERROR);
            $this->redirect('list', 'TemplateManager', NULL, array());
        }
        
        else {
            
            
            // Benoetigte Daten sammeln
            $dataCheckFailed = false;
            $templateDataArray = $this->getTemplateDataArray();
            
                    
            // Pruefen ob Templates vorhanden sind
            $tempFluid = unserialize($templateDataArray['fluid']);
            if(!is_array($tempFluid) || empty($tempFluid)) {
                $headline = 'TypoScript nicht re-/generiert!';
                $message  = 'Das '.$typoScriptFile.' TypoScript konnte re-/generiert werden, da auf dieser Seite anscheinend noch keine Fluid-Templates existieren.';
                $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::WARNING);
                
                $dataCheckFailed = true;
            }

        
            /**
             * @todo:  Pruefen ob in allen Menues ein NO vorhanden ist!!
             */ 
            // $tempFluid = unserialize($templateDataArray['fluid']);
            // if(!is_array($tempFluid) || empty($tempFluid)) {
                // $headline = 'TypoScript nicht re-/generiert!';
                // $message  = 'Das '.$typoScriptFile.' TypoScript konnte re-/generiert werden, da auf dieser Seite anscheinend noch keine Fluid-Templates existieren.';
                // $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::WARNING);
                // $dataCheckFailed = true;
            // }

            /**
             * @todo: hier auch mal die eingebundenen include_statics mitsenden
             * am besten inkl. Versionen um den Generator steuern zu können
             */
            
            // TypoScript generieren
            if(!$dataCheckFailed) {
                         
                $result = $this->pluginService->executeAction("generateTypoScript", $templateDataArray);
                
                
                // Antwort auswerten
                if($result['status']=='success') {
                    
                    
                    // Pfad ermitteln
                    $typoScript = "";
                    $messageOk  = "";
                    $filepath   = "fileadmin/".$this->fluidTemplate->getFileadminDir()."/template/ts/";
                    $relPath    = $filepath;
                    $absPath    = t3lib_div::getFileAbsFileName($relPath);
    
    
                    // setup-TypoScript schreiben
                    $typoScriptFile = "setup.ts";
                    $typoScript = $result['setup'];
                    
                    Tx_Ftm_Service_Backup::backupFile($this->fluidTemplate, $absPath.$typoScriptFile);
                    if(!file_put_contents($absPath.$typoScriptFile, $typoScript)) {
                        $headline = 'TypoScript wurde re-/generiert!';
                        $message  = 'Das '.$typoScriptFile.' TypoScript für dieses FTM-Template wurde re-/generiert, konnte aber nicht in der setup.ts abgespeichert werden.<br />';
                        $message .= 'Bitte prüfen die Datei/Pfad auf Korrektheit und Schreibrechte: '.$absPath.$typoScriptFile;
                        $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::ERROR);
                    }
                    else {
                        
                        // MD5-Hash merken
                        $this->fluidTemplate->setMd5HashSetupTs(md5(serialize($templateDataArray)));
                        $messageOk.= 'Das '.$typoScriptFile.' TypoScript für dieses FTM-Template wurde re-/generiert.';
                    }
                    
                        
                    // constants-TypoScript schreiben
                    $typoScriptFile = "constants.ts";
                    $typoScript = $result['constants'];
                    
                    Tx_Ftm_Service_Backup::backupFile($this->fluidTemplate, $absPath.$typoScriptFile);
                    if(!file_put_contents($absPath.$typoScriptFile, $typoScript)) {
                        $headline = 'TypoScript wurde re-/generiert!';
                        $message  = 'Das '.$typoScriptFile.' TypoScript für dieses FTM-Template wurde re-/generiert, konnte aber nicht in der constants.ts abgespeichert werden.<br />';
                        $message .= 'Bitte prüfen die Datei/Pfad auf Korrektheit und Schreibrechte: '.$absPath.$typoScriptFile;
                        $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::ERROR);
                    }
                    else {
                        
                        // MD5-Hash merken
                        $this->fluidTemplate->setMd5HashConstantsTs(md5(serialize($templateDataArray)));
                        $messageOk.= 'Das '.$typoScriptFile.' TypoScript für dieses FTM-Template wurde re-/generiert.';
                    }
                    
                        
                    // tsConfig-TypoScript schreiben
                    $typoScriptFile = "tsConfig.ts";
                    $typoScript = $result['tsConfig'];
                    
                    Tx_Ftm_Service_Backup::backupFile($this->fluidTemplate, $absPath.$typoScriptFile);
                    if(!file_put_contents($absPath.$typoScriptFile, $typoScript)) {
                        $headline = 'TypoScript wurde re-/generiert!';
                        $message  = 'Das '.$typoScriptFile.' TypoScript für dieses FTM-Template wurde re-/generiert, konnte aber nicht in der tsConfig.ts abgespeichert werden.<br />';
                        $message .= 'Bitte prüfen die Datei/Pfad auf Korrektheit und Schreibrechte: '.$absPath.$typoScriptFile;
                        $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::ERROR);
                    }
                    else {
                        
                        // MD5-Hash merken
                        $this->fluidTemplate->setMd5HashTsConfig(md5(serialize($templateDataArray)));
                        $messageOk.= 'Das '.$typoScriptFile.' TypoScript für dieses FTM-Template wurde re-/generiert.';
                    }
                        
                    
                    // Meldung anzeigen?!
                    if($messageOk!="") {
                        // Template speichern
                        $this->fluidTemplateRepository->update($this->fluidTemplate);
                        $this->flashMessageContainer->add($messageOk, 'TypoScript wurde re-/generiert!', t3lib_FlashMessage::OK);
                    }
                   
    
                }
            }    
            
            $this->redirect('list', 'TemplateManager', NULL, array());
        }
    }

    /**
     * Template-Model als Array holen
     */
    protected function getTemplateDataArray() {
    
        // Template-Model als Array holen
        $templateDataArray = $this->fluidTemplate->toArray();
        
        
        // Grid-Layouts auslesen, damit TypoScript 
        // dafuer generiert werden kann
        $gridLayouts = $this->gridLayoutRepository->findAllWithoutPid();
        $gridLayoutsArray = array();
        foreach($gridLayouts as $gridLayout) {
            $gridLayoutsArray[$gridLayout->getUid()] = $gridLayout->getTitle();
        }
        $templateDataArray['gridLayouts'] = serialize($gridLayoutsArray);
        
        
        // TYPO3-Version ermitteln
        $templateDataArray['typo3Version'] = $this->typo3Version;
        
        
        return $templateDataArray;
    }


    /**
     * Erstellt ein Fluid-Template zu einem FTM-Template
     *
     * @param  string $templateType Fluid-Typ die generiert werden soll
     * @param  string $templateFile Fluid-Datei die generiert werden soll
     * @return void
     * 
     * @author Thomas Deuling <typo3@coding.ms>
     * @since  1.0.0
     */
    public function generateFluidAction($templateType, $templateFile) {


        $found = false;
        $temp = "";


        // Template-Datei nur erstellen,
        // wenn es den Datensatz wirklich gibt
        $fluidTemplates = $this->fluidTemplate->getFluid();
        if(!empty($fluidTemplates)) {
            foreach($fluidTemplates as $tempFluid) {
                
                $temp .= $tempFluid->getTemplateType()."==".$templateType." && ".$tempFluid->getTemplateType()."==".$templateFile."<br/ \n>";
                
                if($tempFluid->getTemplateType()==$templateType && $tempFluid->getTemplateFile()==$templateFile) {
                    
                    // Merken das das Template gefunden wurde
                    $found = true;
                    
                    
                    // Dateiname und Pfad
                    $filepath     = "fileadmin/".$this->fluidTemplate->getFileadminDir()."/template/fluid/".$templateType."s/";
                    $filename     = $templateFile.".html";
                    $relPath      = $filepath.$filename;
                    $absPath      = t3lib_div::getFileAbsFileName($relPath);
                    
                    
                    // Template-Datei erstellen
                    Tx_Ftm_Service_Backup::backupFile($this->fluidTemplate, $absPath);
                    if(file_put_contents($absPath, $tempFluid->getTemplateCode())) {
                        $headline = 'Fluid-'.ucfirst($templateType).' wurde erfolgreich erstellt!';
                        $message  = 'Das '.$templateFile.'.html Fluid-'.ucfirst($templateType).' wurde erfolgreich erstellt.';
                        $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::OK);
                    }
                    else {
                        $headline = 'Fluid-'.ucfirst($templateType).' konnte nicht erstellt werden!';
                        $message  = 'Das '.$templateFile.'.html Fluid-'.ucfirst($templateType).' konnte nicht erstellt werden.<br />';
                        $message .= 'Bitte prüfen Sie den Dateinamen und die Verzeichnisrechte.';
                        $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::ERROR);
                    }
                    
                } 
                
               
            }
        }
        else {
            $temp .="not array";
        }
        
        
        if(!$found) {
            $headline = 'Fluid-'.ucfirst($templateType).' konnte nicht gefunden werden!';
            $message  = 'Der Datensatz zum '.$templateFile.'.html Fluid-'.ucfirst($templateType).' konnte nicht gefunden werden.'.$temp;
            $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::WARNING);
        }


        $this->redirect('list', 'TemplateManager', NULL, array());
    }


  
    /**
     * Erstellt ein Template-Datensatz auf der aktuellen Seite
     *
     * @author Thomas Deuling <typo3@coding.ms>
     * @return void
     * @since 1.0.0
     */
    public function createTemplateAction() {
        
        
        // Template auslesen, falls vorhanden
        $fluidTemplate = $this->fluidTemplateRepository->findOneByPid($this->pid);
        
        
        $this->debug.= "read fluidTemplate on pid:".$this->pid." -> ".get_class($fluidTemplate)."<br>";
        
        // Wenn es noch keinen gibt, erstelle einen
        if(!($fluidTemplate instanceof Tx_Ftm_Domain_Model_Template)) {

            $this->debug.= "create fluidTemplate on pid:".$this->pid."<br>";

            
            // Template erstellen und Standard-Werte einsetzen
            $fluidTemplate = $this->objectManager->create('Tx_Ftm_Domain_Model_Template');
            $fluidTemplate->setPid($this->pid);
            
            
            // Template-Config
            $fluidTemplateConfig = $this->objectManager->create('Tx_Ftm_Domain_Model_TemplateConfig');
            $fluidTemplateConfig->setDefaults();
            $fluidTemplate->setConfig($fluidTemplateConfig);
            
            
            // Template-Meta
            $fluidTemplateMeta = $this->objectManager->create('Tx_Ftm_Domain_Model_TemplateMeta');
            $fluidTemplateMeta->setDefaults();
            $fluidTemplate->setMeta($fluidTemplateMeta);
            
            
            
            /**
             * @ToDo
             * hier noch infos für den Einstieg anzegien
             * 
             * Dein Template wurde mit einer Grundkonfiguration erstellt.
             * Bearbeite nun den FTP-Datensatz und gebe als erstes ein fileadmin-Verzeichnis an, in dem Dein Template liegen soll
             * Benenne dieses Verzeichnis mit bedacht. Am besten wählst Du einen Namen der die 
             * 
             * ..
             * Wechselst Du jetzt wieder in die Übersichts-Ansicht des Template-Managers erstellt dieser automatisiert deine neuen Template-Verzeichnis Struktur
             */
             
             
            // Extensions:t3_less
            // -----------------------------
            $fluidTemplateExt     = $this->objectManager->create('Tx_Ftm_Domain_Model_TemplateExt');
            $fluidTemplateExtConf = $this->objectManager->create('Tx_Ftm_Domain_Model_TemplateExtT3Less');
            $fluidTemplateExt->setExtKey('t3_less');
            $fluidTemplateExt->setExtName('LESS for TYPO3');
            $fluidTemplateExt->setExtVersion('1.0.7');
            $fluidTemplateExt->setExtConfT3Less($fluidTemplateExtConf);
            $fluidTemplate->addExtension($fluidTemplateExt);
            
            /**
             * @ToDo: import.less by default einsetzen
             */
            
            // -----------------------------
            
            
            // Template speichern/persistieren
            // -----------------------------
            $this->fluidTemplateRepository->add($fluidTemplate);
            // -----------------------------
            
            $headline = $this->lang('templateCreatedMessageOkHeadline');
            $message  = $this->lang('templateCreatedMessageOkMessage');
            $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::OK);
        }
        else {
            $headline = $this->lang('templateCreatedMessageWarningHeadline');
            $message  = $this->lang('templateCreatedMessageWarningMessage');
            $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::WARNING);
        }
    
    
        $this->redirect('list', 'TemplateManager', NULL, array());
    }



    /**
     * @param   string      $command: The command which has been sent to processDatamap
     * @param   string      $table: The table we're dealing with
     * @param   mixed       $id: Either the record UID or a string if a new record has been created
     * @param   array       $fieldArray: The record row how it has been inserted into the database
     * @return  void
     * 
     * Erfordert in ext_localconf.php:
       $GLOBALS['TYPO3_CONF_VARS']['SC_OPTIONS']['t3lib/class.t3lib_tcemain.php']['processCmdmapClass'][] 
       = 'EXT:coding_ms_tyma/Classes/Controller/MagentoProductController.php:Tx_CodingMsTyma_Controller_MagentoProductController';
     * 
     */
    // public function processCmdmap_postProcess($command, $table, $id, $value) {
    public function processCmdmap_preProcess($command, $table, $id, $value) {
        
        
        /**
         * @TODO: Im Template festhalen in welcher FTM-Version
         * das letzte mal gespeichert wurde.
         * Liegt die installierte darunter, wird eine Warnung angezeigt
         */
        
        // var_dump($command, $table, $id, $value);
            // die("test");
        
        
        if ($command == 'delete' && (
            $table == 'tx_ftm_domain_model_templatemeta' ||
            $table == 'tx_ftm_domain_model_templateconfig'
            )) {
            // Darf nicht einzeln gelöscht werden
            exit;
        }
        
        // Update wurde hier nicht aufgefangen
        else if ($command == 'update' && (
            $table == 'tx_ftm_domain_model_template' ||
            $table == 'tx_ftm_domain_model_templatelessvariable' ||
            $table == 'tx_ftm_domain_model_templatemeta' ||
            $table == 'tx_ftm_domain_model_templateconfig'
            )) {
            var_dump($command, $table, $id, $value);
            die("test");
        }
        
        // New wurde hier nicht aufgefangen
        else if ($command == 'new' && $table == 'tx_codingmstyma_domain_model_magentoproduct') {
        }

    }
    
    

    /**
     * Wird nach Datenbank-Operationen aufgerufen
     *
     * Erfordert in ext_localconf.php:
     * $GLOBALS['TYPO3_CONF_VARS']['SC_OPTIONS']['t3lib/class.t3lib_tcemain.php']['processDatamapClass'][] 
     * = 'EXT:ftm/Classes/Controller/TemplateManagerController.php:Tx_Ftm_Controller_TemplateManagerController';
     * 
     * @param   string      $command: The command which has been sent to processDatamap
     * @param   string      $table: The table we're dealing with
     * @param   mixed       $id: Either the record UID or a string if a new record has been created
     * @param   array       $fieldArray: The record row how it has been inserted into the database
     * @param   object      $reference: A reference to the TCEmain instance
     * @return  void
     * 
     * 
    public function processDatamap_afterDatabaseOperations($command, $table, $id, &$fieldArray, t3lib_TCEmain &$reference) {
        
        error_reporting(E_ALL);
        ini_set('display_errors', 1);
        
        // Delete wurde hier nicht auf gefangen
        if ($command == 'delete' && $table == 'tx_codingmstyma_domain_model_magentoproduct') {
        }
        else if ($command == 'update' && (
            $table == 'tx_ftm_domain_model_template'
            // ||
            // $table == 'tx_ftm_domain_model_templatelessvariable' ||
            // $table == 'tx_ftm_domain_model_templatemeta' ||
            // $table == 'tx_ftm_domain_model_templateconfig'
            )) {
            
            
        
            // Fluid-TemplateRepository erstellen, falls noch nicht geschehen
            // Wird benoetigt falls ueber afterDatabaseOperations aufgerufen wird
            if(!($this->fluidTemplateRepository instanceof Tx_Ftm_Domain_Repository_TemplateRepository)) {
                $this->fluidTemplateRepository = t3lib_div::makeInstance('Tx_Ftm_Domain_Repository_TemplateRepository');
            }
 
            // Fluid Template auslesen, falls noch nicht geschehen
            $this->pid = $id;
            if(!($this->fluidTemplate instanceof Tx_Ftm_Domain_Model_Template)) {
                
                / **
                 * @var Tx_Ftm_Domain_Model_Template
                 * / 
                $this->fluidTemplate = $this->getTemplate();
            }
            
            
            // Hash neu setzen um zu identifizieren ob 
            // sich die Konfiguration geaendert hat
            $templateDataArray = $this->getTemplateDataArray();
            $this->fluidTemplate->setMd5HashTemplateData(md5(serialize($templateDataArray)));
            $this->fluidTemplateRepository->update($this->fluidTemplate);

        }
        else if ($command == 'new' && $table == 'tx_codingmstyma_domain_model_magentoproduct') {
        }
        
    }
     */

    /**
     * Holt eine Uebersetzung
     * 
     * @param  string $key Schluessel des Sprachwerts
     * @return string Uebersetzung
     */
    protected function lang($key) {
        $extName   = 'Ftm';
        $keyPrefix = 'tx_ftm_domain_model_template';
        return Tx_Extbase_Utility_Localization::translate($keyPrefix.".".$key, $extName);
    }

    /**
     * Create the panel of buttons for submitting the form or otherwise perform operations.
     *
     * @param  string $baseUrl Base-URL fuer die Links
     * @return array  All available buttons as an assoc. array
     */
    protected function getButtons($baseUrl="") {
        
        $buttons = array();
        
        // TYPO3_CMS_Backend_Utility_IconUtility::getSpriteIcon('actions-document-view')
        
        // Seite ansehen
        if(isset($this->pid) && $this->pid>0) { 
            $buttons['view'] = array();
            $buttons['view']['href']    = '#';
            $buttons['view']['onclick'] = 'var previewWin = window.open(\''.$baseUrl.'index.php?id='.$this->pid.'\',\'newTYPO3frontendWindow\');previewWin.focus();';
            $buttons['view']['title']   = $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:labels.showPage', 1);
            $buttons['view']['icon']    = 'actions-document-view';
        }
        
        
        // CSH
        //$buttons['csh'] = TYPO3_CMS_Backend_Utility_BackendUtility::cshItem('_MOD_web_ftm', '', $GLOBALS['BACK_PATH'], '', TRUE);
        
        return $buttons;
        
        // View page
        $buttons['view'] = '<a href="#" onclick="' . htmlspecialchars(TYPO3_CMS_Backend_Utility_BackendUtility::viewOnClick($this->pid, $GLOBALS['BACK_PATH'], TYPO3_CMS_Backend_Utility_BackendUtility::BEgetRootLine($this->pageinfo['uid']))) . '" title="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:labels.showPage', 1) . '">' . TYPO3_CMS_Backend_Utility_IconUtility::getSpriteIcon('actions-document-view') . '</a>';
        // Shortcut
        // if ($GLOBALS['BE_USER']->mayMakeShortcut()) {
            // $buttons['shortcut'] = $this->doc->makeShortcutIcon('id, edit_record, pointer, new_unique_uid, search_field, search_levels, showLimit', implode(',', array_keys($this->MOD_MENU)), $this->MCONF['name']);
        // }
        return $buttons;
    }

    
    /**
     * Prueft ob alle benoetigten Extensions vorhanden sind
     */
    protected function checkRequiredExtenstions() {

        // error_reporting(E_ALL);
        // ini_set('display_errors', 1);
        
        // Erforderlichen Extensions ermitteln
        $requiredExtensions = explode(';', FTM_REQUIRED_EXTENSIONS);
        $messages = array();
        
        // var_dump($requiredExtensions, FTM_REQUIRED_EXTENSIONS);
        // die(FTM_REQUIRED_EXTENSIONS);
         // global $TYPO3_CONF_VARS;
        // global $TYPO3_LOADED_EXT;
                
        // var_dump($TYPO3_CONF_VARS['EXT']['extList']);
        // var_dump($TYPO3_LOADED_EXT['gridelements']);
        // echo "<br><br>";
        // if(t3lib_extMgm::isLoaded('gridelements')) {
            // echo "DDAAA<br><br>";
        // }
        // var_dump($GLOBALS['TCA']['sys_template']['columns']['include_static_file']['config']['items']);
        // echo "<br><br>";
        // exit;
        
        // Standard-Extensions pruefen
        if(!empty($requiredExtensions)) {
            foreach($requiredExtensions as $extension) {
                if(!t3lib_extMgm::isLoaded($extension)) {
                    $messages[] = $extension." Extension konnte nicht gefunden werden";
                }
            }
        }
     
        if($this->fluidTemplate instanceof Tx_Ftm_Domain_Model_Template) {
            if(!t3lib_extMgm::isLoaded('realurl') && $this->fluidTemplate->getConfig()->getSpeakingPaths()=='realurl') {
                $messages[] = "RealURL (ab Version 1.12.6) Extension konnte nicht gefunden werden";
            }
            else if(!t3lib_extMgm::isLoaded('simulatestatic') && $this->fluidTemplate->getConfig()->getSpeakingPaths()=='simulatestatic') {
                $messages[] = "simulatestatic Extension konnte nicht gefunden werden";
            }
        }
        
     
        if(!empty($messages))  {
            if(count($messages)==1) {
                $headline = 'Erforderliche Extension fehlt!';
            }
            else {
                $headline = 'Erforderliche Extensions fehlen!';
            }
            $message = implode('<br />', $messages);
            $this->flashMessageContainer->add($message, $headline, t3lib_FlashMessage::ERROR);
        }
            
        
    }
    
    /**
     * Setzt bzw. aktualisiert ein fileadmin-Verzeichnis
     * 
     * @param  string $fileadminPath fileadmin-Verzeichnis
     */
    protected function setFileadminDir($fileadminPath) {
            

        // Im Sys-Template setzen/aktualisieren
        $messages = $this->sysTemplateService->setFileadminDir($this->pid, $fileadminPath);
        if(isset($messages['ok']) && !empty($messages['ok'])) {
            $headline = 'TypoScript-Datei(en) erstellt!';
            $this->flashMessageContainer->add($messages['ok'], $headline, t3lib_FlashMessage::OK);
        }
        if(isset($messages['error']) && !empty($messages['error'])) {
            $headline = 'TypoScript-Datei(en) konnten nicht erstellt werden!';
            $this->flashMessageContainer->add($messages['error'], $headline, t3lib_FlashMessage::ERROR);
        }
        
        
        // In den t3_less Constants setzen/aktualisieren
        $lessExtension = $this->fluidTemplate->getExtensionByName('t3_less');
        if(!($lessExtension instanceof Tx_Ftm_Domain_Model_TemplateExt)) {
            throw new Exception("FTM-Template doesnt contain the required t3_less object", 1);
        }
        else {
            $lessExtensionConf = $lessExtension->getExtConfT3Less();
            if(!($lessExtensionConf instanceof Tx_Ftm_Domain_Model_TemplateExtT3Less)) {
                throw new Exception("FTM-Template doesnt contain the required t3_less configuration object", 1);
            }
            else {
                $lessExtensionConf->setPathToLessFiles('fileadmin/'.$fileadminPath.'/template/less/');
                $lessExtensionConf->setOutputFolder('fileadmin/'.$fileadminPath.'/template/css/');
            }
        }
        
        
        // Geaendertes Template speichern
        $this->fluidTemplateRepository->update($this->fluidTemplate);
        
    }


    /**
     * Prueft on in der Extension-Konfiguration
     * alle notwendigen Werte vorhanden sind
     * 
     * @return void
     * @since 1.0.0
     */
    protected function validateExtConf() {
        
        if(!isset($this->extConf['pluginCloudHost']) || trim($this->extConf['pluginCloudHost'])=='') {
            throw new Exception("Extension configuration isnt valid! pluginCloudHost not found! Default value is plugincloud.de.", 1);
        }
        
        if(!isset($this->extConf['pcKey']) || trim($this->extConf['pcKey'])=='') {
            throw new Exception("Extension configuration isnt valid! pcKey not found! Default value is public.", 1);
        }
        
        if(!isset($this->extConf['user']) || trim($this->extConf['user'])=='') {
            throw new Exception("Extension configuration isnt valid! user not found! Default value is noUser.", 1);
        }
        
        if(!isset($this->extConf['password']) || trim($this->extConf['password'])=='') {
            throw new Exception("Extension configuration isnt valid! password not found! Default value is noPassword.", 1);
        }
            
    }
    
    /**
     * Prueft ob ein neues Update verfuegbar ist
     * 
     * @since 1.0.1
     */
    protected function checkForUpdates() {
        
        // Aktuelle Versions-Info ermitteln
        $currentVersionJson  = file_get_contents('http://'.$this->extConf['pluginCloudHost'].'/api/ftm/ftm-current-version.json');
        $currentVersionArray = json_decode($currentVersionJson, true);
        $currentVersionParts = explode('.', $currentVersionArray['version']);
        
        // Eigene Version
        $thisVersionParts    = explode('.', FTM_VERSION);
        
        // Major-Release kleiner
        if($thisVersionParts[0]<$currentVersionParts[0]) {
            $updateMessage = "Es ist ein neues Major-Release verfügbar!<br />";
        }
        // Ansonsten kann nur ein Minor-Release oder Patch vorhanden sein 
        else {
            
            // Minor-Release kleiner
            if($thisVersionParts[1]<$currentVersionParts[1]) {
                $updateMessage = "Es ist ein neues Minor-Release verfügbar!<br />";
            }
            // Ansonsten kann nur ein Patch vorhanden sein
            else {
                
                // Patch kleiner
                if($thisVersionParts[2]<$currentVersionParts[2]) {
                    $updateMessage = "Es ist ein neuer Patch verfügbar!<br />";
                }
                // Alles aktuell! :)
                else {
                    return false;
                }
            }
        }
        
        $updateMessage.= "<br />";
        $updateMessage.= "Es wird empfohlen den FTM auf die aktuelle Version zu aktualisieren. Es kann u.U. ein paar Stunden dauern bis die neue Version auch über Das TER verfügbar ist. Downloaden Sie ansonsten die Extension von unserer <a href=\"http://if-20.com/download/\" target=\"_blank\">Website</a>.<br/>";
        $updateMessage.= "Weitere Informationen finden Sie <a href=\"http://if-20.com/hilfe-community/wiki-documentation/fluid-template-manager/wiki/aktuelle-version/\" target=\"_blank\">hier</a>.<br />";
        
        return $updateMessage;
    }

}
?>