<?php
/**
 * Shows one Fluid-Template row
 *
 * @package    TYPO3
 * @subpackage ftm
 * @author     Thomas Deuling <typo3@coding.ms>
 * @since      1.0.0
 */
class Tx_Ftm_ViewHelper_FluidRowViewHelper extends Tx_Fluid_Core_ViewHelper_AbstractViewHelper {

    /**
     * Fluid-Template/Layout/Partial Row
     *
     * @param  Tx_Ftm_Domain_Model_Template $fluidTemplate
     * @param  Tx_Ftm_Domain_Model_TemplateFluid $template
     * @author Thomas Deuling <typo3@coding.ms>
     * @return HTML
     * @since  1.0.0
     */
    public function render(Tx_Ftm_Domain_Model_Template $fluidTemplate, Tx_Ftm_Domain_Model_TemplateFluid $template) {
            
        $tableCells = array();
        $returnHtml = "";
                
                
        // Dateiname und Pfad
        $templateType = $template->getTemplateType();
        $templateFile = $template->getTemplateFile();
        $filepath     = "fileadmin/".$fluidTemplate->getFileadminDir()."/template/fluid/".$templateType."s/";
        $filename     = $templateFile.".html";
        $relPath      = $filepath.$filename;
        $absPath      = t3lib_div::getFileAbsFileName($relPath);
        $imagePath    = "/typo3conf/ext/ftm/Resources/Public/Icons/";
        
        
        // TS-Icon
        $tableCells[] = "<a><img src=\"/typo3conf/ext/ftm/Resources/Public/Icons/fluid.png\"></a>";

        
        // Template-Typ
        $tableCells[] = $templateType;
        
        
        // Template-File
        $tableCells[] = "<a title=\"".$absPath."\">".$filename."</a>";
        
        
        // Datei existiert?
        if(file_exists($absPath)) {
            
            
            /**
             * Pruefen ob im Template auch ein 
             * Backend-Layout zugewiesen ist
             * 
             * @var Tx_Ftm_Domain_Model_BackendLayout
             */
            $backendLayout = $template->getBackendLayout();
            
            if($templateType=='template' && !($backendLayout instanceof Tx_Ftm_Domain_Model_BackendLayout)) {
                $tableCells[] = "<span style=\"color: red\">Kein Backend-Layout zugewiesen!</span>";
            }
            else if($templateType=='template') {
                $backendLayoutEditLink = "<a href=\"#\" onclick=\"window.location.href='alt_doc.php?returnUrl='+T3_THIS_LOCATION+'&amp;edit[backend_layout][".$backendLayout->getUid()."]=edit'; return false;\" title=\"Backend-Layout bearbeiten\"><img src=\"".$imagePath."edit.png\"></a>";
                $tableCells[] = $backendLayoutEditLink.' '.$backendLayout->getTitle();
            }
            else {
                $tableCells[] = '&nbsp;';
            }
            
            
            // Ist Datei und Datensatz-Code identisch!?
            $fileContent = file_get_contents($absPath);
            if($fileContent==$template->getTemplateCode()) {
                $message = "File exists and is up-to-date";
                $tableCells[] = "<span style=\"color: green\">".$message."</span>";
            }
            else {
                $message = "File exists but isn't up-to-date";
                $tableCells[] = "<span style=\"color: orange\">".$message."</span>";
            }
            
           
            // Refresh-Link erstellen
            $uriBuilder = $this->controllerContext->getUriBuilder();
            $arg = array('tx_ftm_web_ftmftm' => array(
                'templateFile' => $templateFile,
                'templateType' => $templateType
                )
            );
            
            $fluidRefreshUri = $uriBuilder->reset()
                          ->setCreateAbsoluteUri(true)
                          ->setArguments($arg)
                          ->uriFor("generateFluid", array(), "TemplateManager");
            
            
            // Link im neuen Fenster oeffnen
            $actions = array();
            $actions[] = "<a href=\"#\" onclick=\"window.location.href='alt_doc.php?returnUrl='+T3_THIS_LOCATION+'&amp;edit[tx_ftm_domain_model_templatefluid][".$template->getUid()."]=edit'; return false;\" title=\"Template bearbeiten\"><img src=\"".$imagePath."fluid_edit.png\"></a>";
            $actions[] = "<a href=\"/".$relPath."\"        title=\"Fluid-".ucfirst($templateType)." (".$filename.") herunterladen\" target=\"_blank\" ><img src=\"".$imagePath."fluid_download.png\"></a>";
            $actions[] = "<a href=\"".$fluidRefreshUri."\" title=\"Fluid-".ucfirst($templateType)." (".$filename.") re/generieren\"><img src=\"".$imagePath."fluid_refresh.png\"></a>";
            // $actions[] = "<a href=\"/".$relPath."\"        title=\"Fluid-".ucfirst($templateType)." (".$filename.") Informationen\" target=\"_blank\"><img src=\"".$imagePath."fluid_information.png\"></a>";
            
          
            // Actions
            $tableCells[] = implode("&nbsp;", $actions);
            
        }
        else {
            
            $tableCells[] = '&nbsp;';
            
            // Status einsetzen
            $message = "File doesn't exist, please generate it!";
            $tableCells[] = "<span style=\"color: red\">".$message."</span>";
            
            
            // Refresh-Link erstellen
            $uriBuilder = $this->controllerContext->getUriBuilder();
            $arg = array('tx_ftm_web_ftmftm' => array(
                'templateFile' => $templateFile,
                'templateType' => $templateType
                )
            );
            
            $fluidRefreshUri = $uriBuilder->reset()
                          ->setCreateAbsoluteUri(true)
                          ->setArguments($arg)
                          ->uriFor("generateFluid", array(), "TemplateManager");
            
            
            // Link im neuen Fenster oeffnen
            $actions = array();
            $actions[] = "<a><img src=\"".$imagePath."empty.png\"></a>";
            $actions[] = "<a><img src=\"".$imagePath."empty.png\"></a>";
            $actions[] = "<a href=\"".$fluidRefreshUri."\" title=\"Fluid-".ucfirst($templateType)." (".$filename.") re/generieren\"><img src=\"".$imagePath."fluid_refresh.png\"></a>";
            $actions[] = "<a><img src=\"".$imagePath."empty.png\"></a>";
            
            // Actions
            $tableCells[] = implode("&nbsp;", $actions);
            
        }
        
        
        return '<td>'.implode('</td><td>', $tableCells).'</td>';
    }

}
?>