<?php
/**
 * Shows one TypoScript row
 *
 * @package    TYPO3
 * @subpackage ftm
 * @author     Thomas Deuling <typo3@coding.ms>
 * @since      1.0.0
 */
class Tx_Ftm_ViewHelper_TypoScriptRowViewHelper extends Tx_Fluid_Core_ViewHelper_AbstractViewHelper {

    /**
     * TypoScript Row
     *
     * @param  Tx_Ftm_Domain_Model_Template $fluidTemplate
     * @param  string $typoScriptFile
     * @author Thomas Deuling <typo3@coding.ms>
     * @return HTML
     * @since  1.0.0
     */
    public function render(Tx_Ftm_Domain_Model_Template $fluidTemplate, $typoScriptFile) {
            
        $md5Hash = "none";
        $generic = false;
        $tableCells = array();
        $returnHtml = "";
        
        if($typoScriptFile=="setup.ts" || $typoScriptFile=="constants.ts" || $typoScriptFile=="tsConfig.ts") {
            $generic = true;
            
            if($typoScriptFile=="setup.ts") {
                $md5Hash = $fluidTemplate->getMd5HashSetupTs();
            }
            else if($typoScriptFile=="constants.ts") {
                $md5Hash = $fluidTemplate->getMd5HashConstantsTs();
            }
            else {
                $md5Hash = $fluidTemplate->getMd5HashTsConfig();
            }
        } 
                
        // Dateiname und Pfad
        $filepath  = "fileadmin/".$fluidTemplate->getFileadminDir()."/template/ts/";
        $relPath   = $filepath.$typoScriptFile;
        $absPath   = t3lib_div::getFileAbsFileName($relPath);
        $imagePath = "/typo3conf/ext/ftm/Resources/Public/Icons/";
        $md5Data   = $fluidTemplate->getMd5HashTemplateData();
        
        // TS-Icon
        $tableCells[] = "<a><img src=\"/typo3conf/ext/ftm/Resources/Public/Icons/ts.png\"></a>";
        
        
        // TS-File
        $tableCells[] = "<a title=\"".$absPath."\">".$typoScriptFile."</a>";
        
        
        // Datei existiert?
        if(file_exists($absPath)) {
            
            //http://dev.if-20.com/typo3/sysext/filelist/mod1/file_list.php?&id=%2Fvar%2Fwww%2Fif-20.com%2Fweb%2Fdev.if-20.com%2Ffileadmin%2Fmediaservice%2Ftemplate%2Fts&SET[bigControlPanel]=1#
            
            
            // Status einsetzen
            if($md5Hash!="none" && $md5Data!=$md5Hash) {
                $tableCells[] = "<span style=\"color: orange\" title=\"".$md5Data."/Data!=File/".$md5Hash."\">File exists but isn't up-to-date</span>";
            }
            else {
                $tableCells[] = "<span style=\"color: green\">File exists</span>";
            }
            
            
            
            // Refresh-Link erstellen
            $uriBuilder = $this->controllerContext->getUriBuilder();
            $arg = array('tx_ftm_web_ftmftm' => array(
                'typoScriptFile'    => $typoScriptFile
                )
            );
            
            $tsRefreshUri = $uriBuilder->reset()
                          ->setCreateAbsoluteUri(true)
                          ->setArguments($arg)
                          ->uriFor("generateTypoScript", array(), "TemplateManager");
            
            
            // Link im neuen Fenster oeffnen
            $actions = array();
            $actions[] = "<a href=\"/".$relPath."\"     title=\"TypoScript (".$typoScriptFile.") herunterladen\" target=\"_blank\" ><img src=\"".$imagePath."ts_download.png\"></a>";
            
            if($generic) {
                $actions[] = "<a href=\"".$tsRefreshUri."\" title=\"TypoScript (".$typoScriptFile.") re/generieren\"><img src=\"".$imagePath."ts_refresh.png\"></a>";
            }
            // else {
                // $actions[] = "<a><img src=\"".$imagePath."empty.png\"></a>";
            // }
//             
//             
            // if($generic) {
                // $actions[] = "<a><img src=\"".$imagePath."empty.png\"></a>";
            // }
            else {
                $editOnClick = 'top.content.list_frame.location.href=top.TS.PATH_typo3+\'file_edit.php?target=' .
                    rawurlencode($absPath) .
                    '&returnUrl=\'+top.rawurlencode(top.content.list_frame.document.location.pathname+top.content.list_frame.document.location.search);return false;';
                $actions['edit'] = '<a href="#" onclick="' . $editOnClick . '" title="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:cm.edit') . '">' . t3lib_iconWorks::getSpriteIcon('actions-page-open') . '</a>';
            }
            
            
            
            // $actions[] = "<a href=\"/".$relPath."\"     title=\"TypoScript (".$typoScriptFile.") Informationen\" target=\"_blank\"><img src=\"".$imagePath."ts_information.png\"></a>";
            
            // Actions
            $tableCells[] = implode("&nbsp;", $actions);
        }
        else {
            // Fuer den unwahrscheinlichen Fall
            // das die Datei nicht existiert
            $message = "File not found";
            $tableCells[] = "<span style=\"color: red\">".$message."</span>";
        }
        
        
        return '<td>'.implode('</td><td>', $tableCells).'</td>';
    }

}
?>